@@ -16,7 +16,7 @@
 #define CRUX_LIGHT(xx, yy) yy.r = xx.r + 56/255.0;yy.g = xx.g + 47/255.0;yy.b = xx.b + 45/255.0;
 #define CRUX_DARK(xx, yy) yy.r = xx.r - 25/255.0;yy.g = xx.g - 27/255.0;yy.b = xx.b - 21/255.0;
 
-GtkStyleClass *parent_style_class;
+static GtkStyleClass *parent_style_class;
 
 static void
 draw_hline (GtkStyle *style,
@@ -276,7 +276,7 @@ paint_button (cairo_t *cr, GtkStyle *style, GtkStateType state_type, GtkShadowTy
 			/* inside shadow */
 			radius = 1.0;
 			cairo_move_to (cr, x + 1.0, y + height - 1.0);
-			cairo_arc (cr, x + radius + 1.0, y + radius + 1.0, radius, M_PI, M_PI * 1.5);
+			cairo_arc (cr, x + radius + 1.0, y + radius + 1.0, radius, G_PI, G_PI * 1.5);
 			cairo_line_to (cr, x + width - 1.0, y + 1.0);
 			cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.22);
 			cairo_stroke (cr);
@@ -346,11 +346,10 @@ paint_shadow (cairo_t *cr, GtkStyle *style,
 	width -= 1.0; height -= 1.0;
 
 	/* outer rectangle */
-	cairo_rectangle (cr, x, y, width, height);
 	if (shadow_type == GTK_SHADOW_OUT || shadow_type == GTK_SHADOW_ETCHED_OUT)
 	{
 		cairo_set_source_rgb (cr, OUTLINE_GRAY);
-		cairo_stroke (cr);
+		ge_cairo_stroke_rectangle (cr, x, y, width, height);
 	}
 	else if (shadow_type == GTK_SHADOW_IN || shadow_type == GTK_SHADOW_ETCHED_IN)
 	{
@@ -362,7 +361,7 @@ paint_shadow (cairo_t *cr, GtkStyle *style,
 		cairo_pattern_add_color_stop_rgba (crp, 1.0, 1.0, 1.0, 1.0, 0.5);
 		cairo_pattern_add_color_stop_rgba (crp, 0.0, .0, .0, .0, 0.2);
 		cairo_set_source (cr, crp);
-		cairo_stroke (cr);
+		ge_cairo_stroke_rectangle (cr, x, y, width, height);
 		cairo_pattern_destroy (crp);
 	}
 
@@ -370,8 +369,6 @@ paint_shadow (cairo_t *cr, GtkStyle *style,
 	x += 1.0; y += 1.0;
 	width -= 2.0; height -= 2.0;
 
-	cairo_rectangle (cr, x, y, width, height);
-
 	/* stroke */
 	if (shadow_type == GTK_SHADOW_OUT || shadow_type == GTK_SHADOW_ETCHED_OUT)
 	{
@@ -383,14 +380,14 @@ paint_shadow (cairo_t *cr, GtkStyle *style,
 		cairo_pattern_add_color_stop_rgba (crp, 0.0, 1.0, 1.0, 1.0, 0.5);
 		cairo_pattern_add_color_stop_rgba (crp, 1.0, .0, .0, .0, 0.2);
 		cairo_set_source (cr, crp);
-		cairo_stroke (cr);
+		ge_cairo_stroke_rectangle (cr, x, y, width, height);
 		cairo_pattern_destroy (crp);
 	}
 	else if (shadow_type == GTK_SHADOW_IN || shadow_type == GTK_SHADOW_ETCHED_IN)
 	{
 		/*TODO: Find a way to calculate this value (same as shadow out outer line)*/
 		cairo_set_source_rgb (cr, OUTLINE_GRAY);
-		cairo_stroke (cr);
+		ge_cairo_stroke_rectangle (cr, x, y, width, height);
 
 		/*
 		// three lines of alpha: 0.22, 0.12, 0.03
@@ -430,11 +427,10 @@ paint_entry_shadow (cairo_t *cr, GtkStyle *style,
 
 
 	/* Outer Line */
-	cairo_rectangle (cr, x, y, width, height);
 	if (focused)
 	{
 		gdk_cairo_set_source_color (cr, &style->light[GTK_STATE_SELECTED]);
-		cairo_stroke (cr);
+		ge_cairo_stroke_rectangle (cr, x, y, width, height);
 	}
 	else
 	{
@@ -443,26 +439,24 @@ paint_entry_shadow (cairo_t *cr, GtkStyle *style,
 		cairo_pattern_add_color_stop_rgb (crp, 0.0, 185/255.0, 189/255.0, 182/255.0);
 		cairo_pattern_add_color_stop_rgb (crp, 1.0, 238/255.0, 238/255.0, 236/255.0);
 		cairo_set_source (cr, crp);
-		cairo_stroke (cr);
+		ge_cairo_stroke_rectangle (cr, x, y, width, height);
 		cairo_pattern_destroy (crp);
 	}
 
 	/* inner Line */
-	cairo_rectangle (cr, x + 1.0, y + 1.0, width - 2.0, height - 2.0);
 	/* TODO: Find a way to calculate these values */
 	if (state_type == GTK_STATE_INSENSITIVE)
 		gdk_cairo_set_source_color (cr, &style->fg [state_type]);
 	else
 		cairo_set_source_rgb (cr, 54/255.0, 52/255.0, 54/255.0);
 
-	cairo_stroke (cr);
+	ge_cairo_stroke_rectangle (cr, x + 1.0, y + 1.0, width - 2.0, height - 2.0);
 
 	/* inner shadow */
 
 	/* make sure background is initialised as shadow is only in top left */
 	gdk_cairo_set_source_color (cr, &style->base[(state_type == GTK_STATE_INSENSITIVE) ? GTK_STATE_INSENSITIVE : GTK_STATE_NORMAL]);
-	cairo_rectangle (cr, x + 2.0, y + 2.0, width - 4.0, height - 4.0);
-	cairo_stroke (cr);
+	ge_cairo_stroke_rectangle (cr, x + 2.0, y + 2.0, width - 4.0, height - 4.0);
 
 	/* draw shadow */
 	cairo_move_to (cr, x + 2.0, y + height - 2.0);
@@ -485,7 +479,7 @@ paint_scrollbar_trough (cairo_t *cr, GtkStyle *style, GtkStateType state_type, G
 
 	#define OFFWHITE 238/255.0, 238/255.0, 238/255.0
 
-
+	/* bevel */
 	ge_gdk_color_to_cairo (&style->white, &br);
 	ge_gdk_color_to_cairo (&style->bg[state_type], &tl);
 	ge_shade_color (&tl, 1.2, &tl);
@@ -500,9 +494,9 @@ paint_scrollbar_trough (cairo_t *cr, GtkStyle *style, GtkStateType state_type, G
 	cairo_fill (cr);
 
 	if (orientation == GTK_ORIENTATION_HORIZONTAL)
-		cairo_rectangle (cr, x, y, width, height * 0.4);
+		cairo_rectangle (cr, x, y, width, height / 2 - 1);
 	else
-		cairo_rectangle (cr, x, y, width * 0.4, height);
+		cairo_rectangle (cr, x, y, width /2 - 1, height);
 
 	cairo_set_source_rgb (cr, OFFWHITE);
 	cairo_fill_preserve (cr);
@@ -512,9 +506,9 @@ paint_scrollbar_trough (cairo_t *cr, GtkStyle *style, GtkStateType state_type, G
 
 
 	if (orientation == GTK_ORIENTATION_HORIZONTAL)
-		cairo_rectangle (cr, x, y + height * 0.6, width, height * 0.4);
+		cairo_rectangle (cr, x, y + height / 2 + 1, width, height  / 2 -1);
 	else
-		cairo_rectangle (cr, x + width * 0.6, y, width * 0.4, height);
+		cairo_rectangle (cr, x + width / 2 + 1, y, width / 2 - 1, height);
 
 	cairo_set_source_rgb (cr, OFFWHITE);
 	cairo_fill_preserve (cr);
@@ -534,17 +528,21 @@ paint_scrollbar_trough (cairo_t *cr, GtkStyle *style, GtkStateType state_type, G
 	}
 
 
+	/* set co-ordinates for fill drawing */
+	x -= 0.5; y -= 0.5; width += 1.0; height += 1.0;
+
 	cairo_rectangle (cr, x, y, width, height);
-	cairo_pattern_add_color_stop_rgba (crp, 0.0, 0.0, 0.0, 0.0, 0.4);
+	cairo_pattern_add_color_stop_rgba (crp, 0.0, 0.0, 0.0, 0.0, 0.5);
 	cairo_pattern_add_color_stop_rgba (crp, gradient_size, 0.0, 0.0, 0.0, 0.0);
-	cairo_pattern_add_color_stop_rgba (crp, 1 - gradient_size, 0.0, 0.0, 0.0, 0.0);
-	cairo_pattern_add_color_stop_rgba (crp, 1.0, 0.0, 0.0, 0.0, 0.4);
+	cairo_pattern_add_color_stop_rgba (crp, 1.0 - gradient_size, 0.0, 0.0, 0.0, 0.0);
+	cairo_pattern_add_color_stop_rgba (crp, 1.0, 0.0, 0.0, 0.0, 0.5);
 
 	cairo_set_source (cr, crp);
 	cairo_fill (cr);
 	cairo_pattern_destroy (crp);
 }
 
+static void
 paint_scale_trough (cairo_t *cr, GtkStyle *style, GtkStateType state_type, GtkOrientation orientation,
 	gdouble x, gdouble y, gdouble width, gdouble height)
 {
@@ -1138,61 +1136,37 @@ draw_arrow (GtkStyle *style,
 	if (arrow_type == (GtkArrowType)4)/*NONE - new in GTK 2.10*/
 		return;
 
+
+	/* random adjustments... */
 	if (DETAIL ("vscrollbar") || DETAIL ("hscrollbar"))
 	{
-		/* add some padding */
-		x++; y++; height--; width--; 
-		if (DETAIL ("hscrollbar"))
-			width--;
-		else
-			height--;
-
-		/* random adjustments... */
 		if (arrow_type == GTK_ARROW_DOWN)
 			y++;
 		else if (arrow_type == GTK_ARROW_RIGHT)
 			x++;
-			
 	}
-	else if (DETAIL ("spinbutton"))
+
+	if (DETAIL ("spinbutton"))
 	{
 		if (arrow_type == GTK_ARROW_DOWN)
 			y+=2;
-		else if (arrow_type == GTK_ARROW_UP)
-			y--;
-
-		x++; width--;
-
 	}
-	else if (DETAIL ("menuitem"))
-	{
-		/* make slightly smaller... */
-		x++;
-		height-=2;
-	} else if (ge_is_in_combo_box (widget) || ge_is_combo_box (widget, FALSE))
-	{
-		x+=2; y+=3; width -= 4; height -= 4;
-		if (ge_is_combo (widget))
-			width--;
-	}
-	else
-	{
-		/* catch all to add some padding... */
-		x++;
-		y++;
-		width -= 2;
-		height -= 2;
-	}
-
-	/* make triangle equilateral */
 	if (arrow_type == GTK_ARROW_UP || arrow_type == GTK_ARROW_DOWN)
-		height = sin (60.0 * 0.017453) * width;
+	{
+		x = x + width / 2 - 2;
+		y = y + height / 2 - 2;
+		height = 4; width = 5;
+	}
 	else if (arrow_type == GTK_ARROW_LEFT || GTK_ARROW_RIGHT)
-		width = sin (60.0 * 0.017453) * height;
+	{
+		x = x + width / 2 - 2;
+		y = y + height / 2 - 2;
+		height = 5; width = 4;
+	}
+
 
 
 	cr = ge_gdk_drawable_to_cairo (window, area);
-
 	switch (arrow_type)
 	{
 		case GTK_ARROW_UP:
@@ -1374,7 +1348,7 @@ draw_option (GtkStyle *style,
 
 	if (!GE_IS_MENU_ITEM (widget))
 	{
-		cairo_arc (cr, cx, cy, radius, 0.0, M_PI * 2);
+		cairo_arc (cr, cx, cy, radius, 0.0, G_PI * 2);
 
 		if (state_type == GTK_STATE_INSENSITIVE)
 		{
@@ -1410,7 +1384,7 @@ draw_option (GtkStyle *style,
 			cairo_set_source_rgb (cr, OUTLINE_GRAY);
 			cairo_stroke (cr);
 
-			cairo_arc (cr, cx, cy, radius - 1.0, 0.0, M_PI * 2);
+			cairo_arc (cr, cx, cy, radius - 1.0, 0.0, G_PI * 2);
 			cairo_set_source_rgba (cr, 1.0, 1.0, 1.0, 0.5);
 			cairo_stroke (cr);
 		}
@@ -1422,7 +1396,7 @@ draw_option (GtkStyle *style,
 	if (shadow_type == GTK_SHADOW_IN)
 	{
 		/* draw check mark */
-		cairo_arc (cr, cx, cy, radius, 0.0, M_PI * 2);
+		cairo_arc (cr, cx, cy, radius, 0.0, G_PI * 2);
 
 		if (state_type == GTK_STATE_INSENSITIVE)
 		{
@@ -1470,14 +1444,14 @@ draw_tab (GtkStyle *style,
 	/* Draws an option menu tab (the up and down pointing arrows)
 	 * TODO: Make this look neater
 	 */
-    	debug ("draw_tab: detail=%s state=%d shadow=%d x=%d y=%d w=%d h=%d\n",
+	debug ("draw_tab: detail=%s state=%d shadow=%d x=%d y=%d w=%d h=%d\n",
 	    detail, state_type, shadow_type, x, y, width, height);
 
 	draw_arrow (style, window, state_type, shadow_type, area, widget, detail,
-		    GTK_ARROW_UP, FALSE, x + width / 2, y - height / 2, width * 0.66, height);
+		    GTK_ARROW_UP, FALSE, x + (width / 2) - 2, y - (height / 2), 7, 7);
 
 	draw_arrow (style, window, state_type, shadow_type, area, widget, detail,
-		    GTK_ARROW_DOWN, FALSE, x + width / 2, y + height / 2 + 1, width * 0.66, height);
+		    GTK_ARROW_DOWN, FALSE, x + (width / 2) - 2, y + (height / 2), 7, 7);
 }
 
 static void
